<?php

/**
 * Created by PhpStorm.
 * User: tnagy
 * Date: 2016.11.29.
 * Time: 16:38
 */
class MM_WPFS_TransactionDataService {

	const KEY_PREFIX = 'wpfs_td_';

	/**
	 * Store transaction data as a transient.
	 *
	 * @param $data MM_WPFS_TransactionData
	 *
	 * @return null|string
	 */
	public function store( $data ) {
		$key = $this->generate_key();
		set_transient( $key, $data );

		return $key;
	}

	/**
	 * @param $data_key
	 *
	 * @return bool|MM_WPFS_TransactionData
	 */
	public function retrieve( $data_key ) {
		if ( is_null( $data_key ) ) {
			return false;
		}
		$prefix_position = strpos( $data_key, self::KEY_PREFIX );
		if ( $prefix_position === false ) {
			return false;
		}
		if ( $prefix_position == 0 ) {
			$data = get_transient( $data_key );

			if ( $data !== false ) {
				delete_transient( $data_key );
			}

			return $data;
		} else {
			return false;
		}
	}

	/**
	 * Generates a random key currently not in use as a transient key.
	 */
	private function generate_key() {
		$key = null;
		do {
			$key = urlencode( self::KEY_PREFIX . crypt( strval( round( microtime( true ) * 1000 ) ), strval( rand() ) ) );
		} while ( get_transient( $key ) !== false );

		return $key;
	}

	public static function create_payment_data( $customer_email, $amount, $product_name, $customer_name, $billing_address, $custom_input_values = null ) {
		$an_instance = new MM_WPFS_TransactionData();

		$an_instance->setCustomerEmail( $customer_email );
		$an_instance->setAmount( $amount );
		$an_instance->setProductName( $product_name );
		$an_instance->setCustomerName( $customer_name );
		$an_instance->setBillingAddress( $billing_address );
		$an_instance->setCustomInputValues( $custom_input_values );

		return $an_instance;
	}

	public static function create_subscription_data( $customer_email, $plan_name, $plan_amount, $setup_fee, $product_name, $customer_name, $billing_address, $custom_input_values ) {
		$an_instance = new MM_WPFS_SubscriptionTransactionData();

		$an_instance->setCustomerEmail( $customer_email );
		$an_instance->setPlanName( $plan_name );
		$an_instance->setPlanAmount( $plan_amount );
		$an_instance->setSetupFee( $setup_fee );
		$an_instance->setProductName( $product_name );
		$an_instance->setCustomerName( $customer_name );
		$an_instance->setBillingAddress( $billing_address );
		$an_instance->setCustomInputValues( $custom_input_values );

		return $an_instance;
	}

}

class MM_WPFS_TransactionData {

	protected $customer_name;
	protected $customer_email;
	protected $billing_address;
	protected $amount;
	protected $product_name;
	protected $custom_input_values;

	/**
	 * @return mixed
	 */
	public function getCustomerName() {
		return $this->customer_name;
	}

	/**
	 * @param mixed $customer_name
	 */
	public function setCustomerName( $customer_name ) {
		$this->customer_name = $customer_name;
	}

	/**
	 * @return mixed
	 */
	public function getCustomerEmail() {
		return $this->customer_email;
	}

	/**
	 * @param mixed $customer_email
	 */
	public function setCustomerEmail( $customer_email ) {
		$this->customer_email = $customer_email;
	}

	/**
	 * @return mixed
	 */
	public function getBillingAddress() {
		return $this->billing_address;
	}

	/**
	 * @param mixed $billing_address
	 */
	public function setBillingAddress( $billing_address ) {
		$this->billing_address = $billing_address;
	}

	/**
	 * @return mixed
	 */
	public function getAmount() {
		return $this->amount;
	}

	/**
	 * @param mixed $amount
	 */
	public function setAmount( $amount ) {
		$this->amount = $amount;
	}

	/**
	 * @return mixed
	 */
	public function getProductName() {
		return $this->product_name;
	}

	/**
	 * @param mixed $product_name
	 */
	public function setProductName( $product_name ) {
		$this->product_name = $product_name;
	}

	/**
	 * @return mixed
	 */
	public function getCustomInputValues() {
		return $this->custom_input_values;
	}

	/**
	 * @param mixed $custom_input_values
	 */
	public function setCustomInputValues( $custom_input_values ) {
		$this->custom_input_values = $custom_input_values;
	}

}

class MM_WPFS_SubscriptionTransactionData extends MM_WPFS_TransactionData {

	protected $plan_name;
	protected $plan_amount;
	protected $setup_fee;

	/**
	 * @return mixed
	 */
	public function getPlanName() {
		return $this->plan_name;
	}

	/**
	 * @param mixed $plan_name
	 */
	public function setPlanName( $plan_name ) {
		$this->plan_name = $plan_name;
	}

	/**
	 * @return mixed
	 */
	public function getPlanAmount() {
		return $this->plan_amount;
	}

	/**
	 * @param mixed $plan_amount
	 */
	public function setPlanAmount( $plan_amount ) {
		$this->plan_amount = $plan_amount;
	}

	/**
	 * @return mixed
	 */
	public function getSetupFee() {
		return $this->setup_fee;
	}

	/**
	 * @param mixed $setup_fee
	 */
	public function setSetupFee( $setup_fee ) {
		$this->setup_fee = $setup_fee;
	}

}